@@ -92,7 +92,7 @@ srs.data.frame <- function(frame, stratid, nsamp, prn) {
   out_frame <- frame[do.call(order, order_frame), ]
   # the nsamp first objects in each stratum are marked for sampling
   out_frame$sampled <-
-    sequence(rle(as.character(frame[, stratid]))$lengths) <=
+    sequence(rle(as.character(out_frame[, stratid]))$lengths) <=
       out_frame[, nsamp]
 
   return(out_frame)
